@@ -74,7 +74,13 @@ public class Medialibrary {
     }
 
     public boolean init(Context context) {
-        mIsInitiated = nativeInit(context.getCacheDir()+ VLC_MEDIA_DB_NAME, context.getExternalFilesDir(null).getAbsolutePath()+ THUMBS_FOLDER_NAME);
+        if (context == null)
+            return false;
+        File cacheDir = context.getCacheDir();
+        File extFilesDir = context.getExternalFilesDir(null);
+        if (extFilesDir == null || !cacheDir.exists() || !extFilesDir.exists())
+            return false;
+        mIsInitiated = nativeInit(cacheDir+ VLC_MEDIA_DB_NAME, extFilesDir.getAbsolutePath()+ THUMBS_FOLDER_NAME);
         return mIsInitiated;
     }
 
@@ -100,9 +106,15 @@ public class Medialibrary {
             nativeDiscover(Tools.encodeVLCMrl(path));
     }
 
-    public void removeFolder(@NonNull String path) {
-        if (mIsInitiated)
-            nativeRemoveEntryPoint(Tools.encodeVLCMrl(path));
+    public void removeFolder(@NonNull String mrl) {
+        if (!mIsInitiated)
+            return;
+        String[] folders = getFoldersList();
+        for (String folder : folders) {
+            if (!folder.equals(mrl) && folder.contains(mrl))
+                removeFolder(folder);
+        }
+        nativeRemoveEntryPoint(Tools.encodeVLCMrl(mrl));
     }
 
     public String[] getFoldersList() {
